Enum Request

#[non_exhaustive]
pub enum Request<'a> { CreatePool { fd: BorrowedFd<'a>, size: i32, }, Release, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CreatePool

create a shm pool

Create a new wl_shm_pool object.

The pool can be used to create shared memory based buffer objects. The server will mmap size bytes of the passed file descriptor, to use as backing memory for the pool.

Fields

fd: BorrowedFd<'a>

file descriptor for the pool

size: i32

pool size, in bytes



Release

release the shm object

Using this request a client can tell the server that it is not going to use the shm object anymore.

Objects created via this interface remain unaffected.

This is a destructor, once sent this object cannot be used any longer. Only available since version 2 of the interface

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message