Struct WlShm

pub struct WlShm { /* private fields */ }
Available on crate feature wayland and Linux only.
shared memory support

A singleton global object that provides support for shared memory.

Clients can create wl_shm_pool objects using the create_pool request.

On binding the wl_shm object one or more format events are emitted to inform clients about the valid pixel formats that can be used for buffers.

See also the Event enum for this interface.

Implementations



impl WlShm

pub fn create_pool<U, D>( &self, fd: BorrowedFd<'_>, size: i32, qh: &QueueHandle<D>, udata: U, ) -> WlShmPool
where U: Send + Sync + 'static, D: Dispatch<WlShmPool, U> + 'static,

create a shm pool

Create a new wl_shm_pool object.

The pool can be used to create shared memory based buffer objects. The server will mmap size bytes of the passed file descriptor, to use as backing memory for the pool.

pub fn release(&self)

release the shm object

Using this request a client can tell the server that it is not going to use the shm object anymore.

Objects created via this interface remain unaffected.